Packet and socket optimisations

Sending/receiving data on a socket is roughly 5.5x faster, after removing data copies and buffer re-allocations.
This commit is contained in:
Fred Nicolson
2017-01-25 22:57:11 +00:00
parent 6b2947932a
commit fad7d0b81f
11 changed files with 148 additions and 205 deletions
+1
View File
@@ -3,6 +3,7 @@
//
#include <thread>
#include <mutex>
#include "frnetlib/SocketSelector.h"
namespace fr